==> download.php?FileName=terralib-5.3.3-ubuntu-16.04.tar.gz: opt/terralib/5.3.3/include/terralib/qt/widgets/rp/ContrastDialogForm.h <==
/*  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

    This file is part of the TerraLib - a Framework for building GIS enabled applications.

    TerraLib is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License,
    or (at your option) any later version.

    TerraLib is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with TerraLib. See COPYING. If not, write to
    TerraLib Team at <terralib-team@terralib.org>.
 */

/*!
  \file terralib/qt/widgets/rp/ContrastDialogForm.h

  \brief This file defines a class for a Contrast dialog.
*/

#ifndef __TERRALIB_QT_WIDGETS_RP_INTERNAL_CONTRASTDIALOGFORM_H
#define __TERRALIB_QT_WIDGETS_RP_INTERNAL_CONTRASTDIALOGFORM_H

// TerraLib
#ifndef Q_MOC_RUN
#include "../../../maptools/AbstractLayer.h"
#include "../../../qt/widgets/rp/RpToolsWidget.h"
#endif
#include "../../../rp/Contrast.h"
#include "../../../se/ChannelSelection.h"
#include "../../../qt/widgets/canvas/MapDisplay.h"
#include "../Config.h"
#include "OutputRasterWidget.h"

// STL
#include <memory>

// Qt
#include <qcombobox.h>
#include <QDialog>
#include <QActionGroup>

// Forward declaration
namespace Ui { class ContrastDialogForm; }

namespace te
{
  namespace qt
  {
    namespace af
    {
      namespace evt
      {
        struct Event;
      }
    }

    namespace widgets
    {
      class RasterHistogramWidget;

      /*!
        \class ContrastDialogForm

        \brief This class is GUI used to define the contrast parameters for the RP constast operation.
      */
      class TEQTWIDGETSEXPORT ContrastDialogForm : public QDialog
      {
        Q_OBJECT

        public:

          ContrastDialogForm(QWidget* parent = 0);

          ~ContrastDialogForm();

        public:

          void resetWindow(te::map::AbstractLayerPtr layer);

          /*!
            \brief This method is used to set the selected layer for contrast operation
            
            \param layer The layer ptr 

            \note This layer MUST HAVE a valid raster object.
          */
          void set(te::map::AbstractLayerPtr layer);

          void setConfigurations();

          void setMapDisplay(te::qt::widgets::MapDisplay* mapDisplay);

          void setActionGroup(QActionGroup* actionGroup);

          te::map::AbstractLayerPtr get();

          te::rp::Contrast::InputParameters getInputParams();

          te::map::AbstractLayerPtr getOutputLayer();

          void onMapDisplayExtentChanged();

        protected:

          void fillContrastTypes();

          void listBands();

          void applyPreview();

          void drawPreview(te::rst::Raster* raster);

          void drawGeom();

          void setDefaultValues(int contrastType);

          void drawHistogram();

          void getRasterFromROI();

          bool execute();

          void clearCanvas();

          te::se::ChannelSelection* getChannelSelection();

          void closeEvent(QCloseEvent* e);

        protected slots:

          void onAllImageRadioButtonToggled(bool isChecked);

          void onContrastTypeComboBoxActivated(int index);

          void onCellClicked(int row, int column);

          void onCellDoubleClicked(int row, int column);

          void onCellChanged(int row, int column);

          void onMinValueSelected(int value, int band);

          void onMinValueSelected(double value, int band);

          void onMaxValueSelected(int value, int band);

          void onMaxValueSelected(double value, int band);

          void onOkPushButtonClicked();

          void onPreviewCheckBoxToggled(bool isChecked);

          void onRoiRadioButtonToggled(bool isChecked);

          void onVisibleAreaRadioButtonToggled(bool isChecked);

          void onApplicationTriggered(te::qt::af::evt::Event* e);

          void onEnvelopeAcquired(te::gm::Envelope env);

          void onBandChecked();

          void onResetValuesToolButtonClicked();

        signals:

          void addLayer(te::map::AbstractLayerPtr layer);

          void closeTool();

        private:

          std::unique_ptr<Ui::ContrastDialogForm> m_ui;
          std::unique_ptr<te::qt::widgets::RpToolsWidget> m_navigator;
          std::unique_ptr<te::qt::widgets::RasterHistogramWidget> m_histogramWidget;

          te::map::AbstractLayerPtr m_layer;
          te::qt::widgets::OutputRasterWidget* m_outputWidget;
          te::map::AbstractLayerPtr m_outputLayer;
          te::qt::widgets::MapDisplay* m_mapDisplay;

          std::unique_ptr<te::rst::Raster> m_raster;
          std::unique_ptr<te::gm::Geometry> m_geom;

          std::vector<double> m_minValue;
          std::vector<double> m_maxValue;
          std::string m_lastText;

          bool m_bandChecked;
          bool m_updatePreview;
      };

    } // end namespace widgets
  }   // end namespace qt
}     // end namespace te

#endif  // __TERRALIB_QT_WIDGETS_RP_INTERNAL_CONTRASTDIALOGFORM_H

==> download.php?FileName=terralib-5.4.0-ubuntu-16.04.tar.gz: opt/terralib/5.4.0/include/terralib/qt/widgets/rp/ContrastDialogForm.h <==
/*  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

    This file is part of the TerraLib - a Framework for building GIS enabled applications.

    TerraLib is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License,
    or (at your option) any later version.

    TerraLib is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with TerraLib. See COPYING. If not, write to
    TerraLib Team at <terralib-team@terralib.org>.
 */

/*!
  \file terralib/qt/widgets/rp/ContrastDialogForm.h

  \brief This file defines a class for a Contrast dialog.
*/

#ifndef __TERRALIB_QT_WIDGETS_RP_INTERNAL_CONTRASTDIALOGFORM_H
#define __TERRALIB_QT_WIDGETS_RP_INTERNAL_CONTRASTDIALOGFORM_H

// TerraLib
#ifndef Q_MOC_RUN
#include "../../../maptools/AbstractLayer.h"
#include "../../../qt/widgets/rp/RpToolsWidget.h"
#endif
#include "../../../rp/Contrast.h"
#include "../../../se/ChannelSelection.h"
#include "../../../qt/widgets/canvas/MapDisplay.h"
#include "../Config.h"
#include "InputLayerWidget.h"
#include "OutputRasterWidget.h"

// STL
#include <memory>

// Qt
#include <qcombobox.h>
#include <QDialog>
#include <QActionGroup>

// Forward declaration
namespace Ui { class ContrastDialogForm; }

namespace te
{
  namespace qt
  {
    namespace af
    {
      namespace evt
      {
        struct Event;
      }
    }

    namespace widgets
    {
      class RasterHistogramWidget;

      /*!
        \class ContrastDialogForm

        \brief This class is GUI used to define the contrast parameters for the RP constast operation.
      */
      class TEQTWIDGETSEXPORT ContrastDialogForm : public QDialog
      {
        Q_OBJECT

        public:

          ContrastDialogForm(QWidget* parent = 0);

          ~ContrastDialogForm();

        public:

          void resetWindow(te::map::AbstractLayerPtr layer);

          /*!
            \brief This method is used to set the selected layer for contrast operation
            
            \param layer The layer ptr 

            \note This layer MUST HAVE a valid raster object.
          */
          void setList(std::list<te::map::AbstractLayerPtr>& layerList);

          void setConfigurations();

          void setMapDisplay(te::qt::widgets::MapDisplay* mapDisplay);

          void setActionGroup(QActionGroup* actionGroup);

          te::map::AbstractLayerPtr get();

          te::rp::Contrast::InputParameters getInputParams();

          te::map::AbstractLayerPtr getOutputLayer();

          void onMapDisplayExtentChanged();

        protected:

          void fillContrastTypes();

          void listBands();

          void applyPreview();

          void drawPreview(te::rst::Raster* raster);

          void drawGeom();

          void setDefaultValues(int contrastType);

          void drawHistogram();

          void getRasterFromROI();

          bool execute();

          void setDisableInterface(bool enabled);

          void clearCanvas();

          te::se::ChannelSelection* getChannelSelection();

          void closeEvent(QCloseEvent*);

        protected slots:

          void onAllImageRadioButtonToggled(bool isChecked);

          void onContrastTypeComboBoxActivated(int index);

          void onCellClicked(int row, int column);

          void onCellDoubleClicked(int row, int column);

          void onCellChanged(int row, int column);

          void onMinValueSelected(int value, int band);

          void onMinValueSelected(double value, int band);

          void onMaxValueSelected(int value, int band);

          void onMaxValueSelected(double value, int band);

          void onOkPushButtonClicked();

          void layerChanged();

          void onApplyPreviewClicked();

          void onDrawHistogramClicked();

          void onRoiRadioButtonToggled(bool isChecked);

          void onVisibleAreaRadioButtonToggled(bool isChecked);

          void onApplicationTriggered(te::qt::af::evt::Event* e);

          void onEnvelopeAcquired(te::gm::Envelope env);

          void onBandChecked();

          void onResetValuesToolButtonClicked();

        signals:

          void addLayer(te::map::AbstractLayerPtr layer);

          void closeTool();

        private:

          std::unique_ptr<Ui::ContrastDialogForm> m_ui;
          std::unique_ptr<te::qt::widgets::RpToolsWidget> m_navigator;
          std::unique_ptr<te::qt::widgets::RasterHistogramWidget> m_histogramWidget;

          te::map::AbstractLayerPtr m_layer;
          te::qt::widgets::InputLayerWidget* m_inputWidget;
          te::qt::widgets::OutputRasterWidget* m_outputWidget;
          te::map::AbstractLayerPtr m_outputLayer;
          te::qt::widgets::MapDisplay* m_mapDisplay;

          std::unique_ptr<te::rst::Raster> m_raster;
          std::unique_ptr<te::gm::Geometry> m_geom;

          std::vector<double> m_minValue;
          std::vector<double> m_maxValue;
          std::string m_lastText;

          bool m_updatePreview;
          bool m_bandChecked;
      };

    } // end namespace widgets
  }   // end namespace qt
}     // end namespace te

#endif  // __TERRALIB_QT_WIDGETS_RP_INTERNAL_CONTRASTDIALOGFORM_H
